/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.droids.api;

import java.net.URI;
import java.util.Collection;
import java.util.Date;


/**
 * Simple extension of a {@link Task}. Adding from/to link and the last
 * modified attribute to the task object.
 * 
 * @version 1.0
 * 
 */
public interface Link extends Task {
  /**
   * @return the URI to this link
   */
  URI getURI();

  /**
   * @return the Anchor text for this link
   */
  String getAnchorText();
  
  /**
   * From where the link was created
   * 
   * @return the parent link from where the link was coming from
   */
  Link getFrom();

  /**
   * To where the link is pointing to
   * 
   * @return the location where the link is pointing to
   */
  Collection<URI> getTo();

  /**
   * last modified date
   * 
   * @return last modified date
   */
  Date getLastModifiedDate();
}
