/*
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied.  See the License for the
* specific language governing permissions and limitations
* under the License.
*/
package org.apache.droids.protocol.file;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URI;

import org.apache.droids.api.ManagedContentEntity;
import org.apache.droids.api.Parse;
import org.apache.droids.api.Protocol;

public class FileProtocol implements Protocol {

  FileInputStream fileInputStream=null;

  @Override
  public boolean isAllowed(URI uri) {
    File file = new File(extractLocation(uri));
    return file.canRead();
  }

  @Override
  public ManagedContentEntity load(URI uri) throws IOException {
    File file = new File(extractLocation(uri));
    return new FileContentEntity(file);
  }

  private String extractLocation(URI uri) {
    String location = uri.toString();
    final int start = location.indexOf("://");
    if(start>-1){
      location = location.substring(start+3);
    }
    return location;
  }

  static class FileContentEntity implements ManagedContentEntity {
    
    private final File file;
    private final String mimeType;
    private final String charset;

    private Parse parse = null;
    
    public FileContentEntity(File file) throws IOException {
      super();
      this.file = file;
      String s = file.getName().toLowerCase();
      if (s.endsWith(".html") || s.endsWith(".htm")) {
        this.mimeType = "text/html";
        this.charset = "ISO-8859-1";
      } else if (s.endsWith(".txt")) {
        this.mimeType = "text/plain";
        this.charset = "ISO-8859-1";
      } else {
        this.mimeType = "binary/octet-stream";
        this.charset = null;
      }
    }

    @Override
    public InputStream obtainContent() throws IOException {
      return new BufferedInputStream(new FileInputStream(file));
    }

    @Override
    public void finish() {
    }

    @Override
    public String getMimeType() {
      return mimeType;
    }

    @Override
    public String getCharset() {
      return charset;
    }

    @Override
    public Parse getParse() {
      return this.parse;
    }

    @Override
    public void setParse(Parse parse) {
      this.parse = parse;
    }

  }
  
}
